@@ -1,9 +1,12 @@
 #' @title Reduce cardinality in categorical variable by automatic grouping
-#' @description Reduce the cardinality of an input variable based on a target -binary by now- variable based on attribitues of accuracy and representativity, for both input and target variable. It uses a cluster model to create the new groups. Full documentation can be found at: \url{https://livebook.datascienceheroes.com/data-preparation.html#high_cardinality_predictive_modeling}
+#' @description Reduce the cardinality of an input variable based on a target -binary by now- variable based on attribitues of accuracy and representativity,
+#'  for both input and target variable. It uses a cluster model to create the new groups.
+#'   Full documentation can be found at:
+#'   \url{https://livebook.datascienceheroes.com/data-preparation.html#high_cardinality_predictive_modeling}
 #' @param data data frame source
 #' @param input categorical variable indicating
 #' @param target string of the variable to optimize the re-grouping
-#' @param n_groups number of groups for the new category based on str_input, normally between 3 and 10.
+#' @param n_groups number of groups for the new category based on input, normally between 3 and 10.
 #' @param model is the clustering model used to create the grouping, supported models: "kmeans" (default) or "hclust" (hierarchical clustering).
 #' @param seed optional, random number used internally for the k-means, changing this value will change the model
 #' @examples
@@ -12,11 +15,11 @@
 #' auto_grouping(data=data_country, input='country', target="has_flu", n_groups=8)
 #' }
 #' @return A list containing 3 elements: recateg_results which contains the description of the target variable with the new groups;
-#' df_equivalence is a data frame containing the str_input category and the new category; fit_cluster which is the cluster model used to do the re-grouping
+#' df_equivalence is a data frame containing the input category and the new category; fit_cluster which is the cluster model used to do the re-grouping
 #' @export
 auto_grouping <- function(data, input, target, n_groups, model="kmeans", seed=999)
 {
-	data[, input]=as.character(data[, input])
+	data[[input]]=as.character(data[[input]])
 
 	df_categ=categ_analysis(data, input , target)
 
