@@ -1,68 +1,12 @@
-#' @title Get model perfomance metrics (KS, AUC and ROC)
-#' @description NOTE: This function will be deprecated! Get model performance for tree models (rpart library), or glm. It returns quality metrics: AUC (Area Under ROC Curve) and KS (Kolmogorov-Smirnov), and plots the ROC curve.
-#' @param fit model, it could be any of the following: decision tree from rpart package, glm model or randomForest.
-#' @param data data frame used to build the model. Also it supports data for testing, (it has to contain same columns as training data.
-#' @param target_var It's the name of the column used as target/outcome. It's an string value, write it between apostrohpe.
-#' @examples
-#' fit_glm=glm(has_heart_disease ~ age + oldpeak, data=heart_disease, family = binomial)
-#' model_performance(fit=fit_glm, data = heart_disease, target_var = "has_heart_disease")
-#' @return None.
-#' @export
-model_performance <- function (fit, data, target_var)
-{
-	if(grepl("glm", as.character(fit$call))[1]) {
-		scr = predict(fit, data)
-	} else if(grepl("rpart", as.character(fit$call))[1]) {
-		scr = predict(fit, data)[,2] } else if(grepl("randomForest", as.character(fit$call))[1]) {
-			scr = predict(fit, data, type = "prob")[, 2]
-		} else {
-			print("Model not supported")
-		}
-
-
-	## Get prediction ROCR object
-	pred = prediction(scr, data[,target_var])
-
-	## Plot ROC
-	perfROC = performance(pred, "tpr", "fpr")
-	plot(perfROC, col=rainbow(10))
-	abline(a=0,b=1)
-	grid()
-
-	## AUC
-	auc=performance(pred,"auc")@y.values[[1]]
-	sprintf("AUC: %0.3f", round(auc,3))
-
-	## KS
-	ks=max(attr(perfROC, "y.values")[[1]] - (attr(perfROC, "x.values")[[1]]))
-	sprintf("KS: %0.3f", round(ks,3))
-
-	## Accuracy
-	perfAcc = performance(pred, "acc")
-	max(perfAcc@y.values[[1]])
-
-	# Table creation
-	dfAcc=data.frame(acc=perfAcc@y.values[[1]], cutoff=perfAcc@x.values[[1]])
-
-	## Metrics table
-	dataMetrics=data.frame(
-		AUC=round(auc,3),
-		KS=round(ks,3)
-	)
-
-	pandoc.table(dataMetrics)
-}
-
-
 #' @title Sampling training and test data
 #' @description Split input data into training and test set, retrieving always same sample by setting the seed.
 #' @param data input data source
 #' @param percentage_tr_rows percentage of training rows, range value from 0.1 to 0.99, default value=0.8 (80 percent of training data)
 #' @param seed to generate the sample randomly, default value=987
 #' @examples
-#' ## Training and test data. Percentage of training cases default value=80%.
+#' # Training and test data. Percentage of training cases default value=80%.
 #' index_sample=get_sample(data=heart_disease, percentage_tr_rows=0.8)
-#' ## Generating the samples
+#' # Generating the samples
 #' data_tr=heart_disease[index_sample,]
 #' data_ts=heart_disease[-index_sample,]
 #' @return TRUE/FALSE vector same length as 'data' param. TRUE represents that row position is for training data
@@ -81,24 +25,37 @@ get_sample <- function(data, percentage_tr_rows=0.8, seed=987)
 #' Higher values at the beginning of the population implies a better model. More info at:
 #'  \url{https://livebook.datascienceheroes.com/model-performance.html#scoring_data}
 #' @param data input data source
-#' @param str_score the variable which contains the score number, or likelihood of being positive class
-#' @param str_target target binary variable indicating class label
+#' @param score the variable which contains the score number, or likelihood of being positive class
+#' @param target target binary variable indicating class label
+#' @param str_score THIS PARAMETER WILL BE DEPRECATED. Please use 'score' insted. Only name changes, not functionality.
+#' @param str_target THIS PARAMETER WILL BE DEPRECATED. Please use 'target' insted. Only name changes, not functionality.
 #' @param q_segments quantity of segments to split str_score, valid values: 5, 10 or 20
 #' @examples
 #' fit_glm=glm(has_heart_disease ~ age + oldpeak, data=heart_disease, family = binomial)
 #' heart_disease$score=predict(fit_glm, newdata=heart_disease, type='response')
-#' gain_lift(data=heart_disease,str_score='score',str_target='has_heart_disease')
+#' gain_lift(data=heart_disease, score='score', target='has_heart_disease')
 #'
 #' @return lift/gain table, column: gain implies how much positive cases are catched if the cut point to define the
 #' positive class is set to the column "Score Point"
 #' @export
-gain_lift <- function(data, str_score, str_target, q_segments=10)
+gain_lift <- function(data, score, target, str_score, str_target, q_segments=10)
 {
+	if(!missing(str_score))
+	{
+		score=str_score
+		.Deprecated(msg="Parameter 'str_score' will be deprecated, please use 'score' insted (only name changed, not its functionality)")
+	}
+
+	if(!missing(str_target))
+	{
+		target=str_target
+		.Deprecated(msg = "Parameter 'str_target' will be deprecated, please use 'target' insted (only name changed, not its functionality)")
+	}
+
 	options(scipen = 999)
 	data=data.frame(data)
 	# The negative score produces that the highest score are at the top
-	# data=heart_disease; str_score='score'; str_target='has_heart_disease'; q_segments='5'
-	data$neg_score=-data[[str_score]]
+	data$neg_score=-data[[score]]
 
 	# Valid values for q_segments
 	if(q_segments<1 | missing(q_segments)){
@@ -109,13 +66,13 @@ gain_lift <- function(data, str_score, str_target, q_segments=10)
 
 	quantile_cuts=quantile(data$neg_score, probs=seq_v)
 
-	data[,str_target]=as.character(data[,str_target])
+	data[[target]]=as.character(data[[target]])
 
-	grp=group_by(data, data[,str_target]) %>% summarise(q=n()) %>% arrange(q)
+	grp=group_by(data, data[,target]) %>% summarise(q=n()) %>% arrange(q)
 
 	less_representative_class=as.character(grp[1,1])
 
-	lift_table=round(100*sapply(quantile_cuts, function(x) sum(data[data$neg_score<=x, str_target]==less_representative_class))/sum(data[, str_target]==less_representative_class),2)
+	lift_table=round(100*sapply(quantile_cuts, function(x) sum(data[data$neg_score<=x, target]==less_representative_class))/sum(data[, target]==less_representative_class),2)
 
 	lift_res=rbind(lift_table,-quantile_cuts)
 	rownames(lift_res)=c("Gain", "Score.Point")
